@@ -133,7 +133,7 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>"
 
 
 import re
-import collections
+from collections.abc import Mapping, MutableSequence
 
 
 #
@@ -273,7 +273,7 @@ def jpath_values(structure, jpath):
         # Process all currently active nodes.
         for node in nodes_a:
             key = chnk['n']
-            if not isinstance(node, dict) and not isinstance(node, collections.Mapping):
+            if not isinstance(node, dict) and not isinstance(node, Mapping):
                 continue
 
             # Process indexed nodes.
@@ -281,7 +281,7 @@ def jpath_values(structure, jpath):
                 idx = chnk['i']
                 # Skip the node, if the key does not exist, the value is not
                 # a list-like object or the list is empty.
-                if not key in node or not (isinstance(node[key], (list, collections.MutableSequence))) or not node[key]:
+                if not key in node or not (isinstance(node[key], (list, MutableSequence))) or not node[key]:
                     continue
                 try:
                     # Handle '*' special index - append all nodes.
@@ -300,7 +300,7 @@ def jpath_values(structure, jpath):
                     continue
 
                 # Handle list values - expand them.
-                if isinstance(node[key], (list, collections.MutableSequence)):
+                if isinstance(node[key], (list, MutableSequence)):
                     for i in node[key]:
                         nodes_b.append(i)
                 # Handle scalar values.
@@ -369,7 +369,7 @@ def jpath_set(structure, jpath, value, overwrite = True, unique = False):
     for i, chnk in enumerate(chunks):
         key = chnk['n']
 
-        if not isinstance(current, dict) and not isinstance(current, collections.Mapping):
+        if not isinstance(current, dict) and not isinstance(current, Mapping):
             raise JPathException("Expected dict-like structure to attach node '{}'".format(chnk['p']))
 
         # Process indexed nodes.
@@ -379,7 +379,7 @@ def jpath_set(structure, jpath, value, overwrite = True, unique = False):
             # Automatically create nodes for non-existent keys.
             if not key in current:
                 current[key] = []
-            if not isinstance(current[key], list) and not isinstance(current[key], collections.MutableSequence):
+            if not isinstance(current[key], list) and not isinstance(current[key], MutableSequence):
                 raise JPathException("Expected list-like object under structure key '{}'".format(key))
 
             # Detection of the last JPath chunk - node somewhere in the middle.
@@ -426,7 +426,7 @@ def jpath_set(structure, jpath, value, overwrite = True, unique = False):
                 # Automatically create nodes for non-existent keys.
                 if not key in current:
                     current[key] = {}
-                if not isinstance(current[key], dict) and not isinstance(current[key], collections.Mapping):
+                if not isinstance(current[key], dict) and not isinstance(current[key], Mapping):
                     raise JPathException("Expected dict-like object under structure key '{}'".format(key))
 
                 current = current[key]
@@ -464,7 +464,7 @@ def jpath_unset(structure, jpath):
         for node in nodes_a:
             key = chnk['n']
 
-            if not isinstance(node, dict) and not isinstance(node, collections.Mapping):
+            if not isinstance(node, dict) and not isinstance(node, Mapping):
                 raise JPathException("Expected dict-like structure to drop node '{}'".format(chnk['p']))
 
             # Process indexed nodes.
@@ -474,7 +474,7 @@ def jpath_unset(structure, jpath):
                 # Skip nodes for non-existent keys.
                 if not key in node:
                     continue
-                if not isinstance(node[key], list) and not isinstance(node[key], collections.MutableSequence):
+                if not isinstance(node[key], list) and not isinstance(node[key], MutableSequence):
                     raise JPathException("Expected list-like object under structure key '{}'".format(key))
 
                 # Detection of the last JPath chunk - node somewhere in the middle.
@@ -513,7 +513,7 @@ def jpath_unset(structure, jpath):
                     if isinstance(node[key], list):
                         nodes_b.extend(node[key])
                         continue
-                    if not isinstance(node[key], dict) and not isinstance(node[key], collections.Mapping):
+                    if not isinstance(node[key], dict) and not isinstance(node[key], Mapping):
                         raise JPathException("Expected dict-like object under structure key '{}'".format(key))
                     nodes_b.append(node[key])
 
