@@ -41,8 +41,8 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 
 
 import re
-import collections
 import datetime
+from collections.abc import MutableSequence
 
 from pynspect.rules import FilteringRuleException
 
@@ -524,7 +524,7 @@ def _to_numeric(val):
     return float(val)
 
 
-class ListIP(collections.MutableSequence):
+class ListIP(MutableSequence):
     """
     Special list implementation designed to provide special handling of 'IN' operator.
     When item is being compared using 'IN' operator with this list, the IN operation
